package ar.com.trabajos.broker.client.presenter;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.Map;

import ar.com.trabajos.broker.client.BrokerServiceAsync;
import ar.com.trabajos.broker.client.event.PedirCotizacionEvent;
import ar.com.trabajos.broker.client.messages.Mensajes;
import ar.com.trabajos.broker.client.view.FormAutoView;
import ar.com.trabajos.broker.shared.entities.DatosFormAutoDTO;
import ar.com.trabajos.broker.shared.entities.RequestDTO;
import ar.com.trabajos.broker.shared.enums.DatosAutoEnum;
import ar.com.trabajos.broker.shared.enums.DatosPersonaEnum;

import com.google.gwt.event.shared.HandlerManager;
import com.google.gwt.user.client.rpc.AsyncCallback;
import com.google.gwt.user.client.ui.HasWidgets;

import dacite.DBAnnotation;

public class FormAutoPresenter implements Presenter, 
FormAutoView.Presenter {  

	
	private final BrokerServiceAsync rpcService;
	private final HandlerManager eventBus;
	private final FormAutoView view;

	public FormAutoPresenter(BrokerServiceAsync rpcService, 
			HandlerManager eventBus, FormAutoView view, HashMap<DatosPersonaEnum, String> datosPersona) {
		this.rpcService = rpcService;
		this.eventBus = eventBus;
		this.view = view;
		this.view.setPresenter(this);
		this.view.setDatosPersona(datosPersona);
		if (!view.marcasFetcheadas()){
			view.mostrarCargandoMarcas();
			this.obtenerDatos();
		}
	}

	private void obtenerDatos() {
		rpcService.obtenerDatosAuto(new AsyncCallback<DatosFormAutoDTO>() {

			
			public void onFailure(Throwable caught) {
				view.agregarUso(Mensajes.LOADING_ERROR);
				view.agregarMarca(-1, Mensajes.LOADING_ERROR);

			}
			
			
			public void onSuccess(DatosFormAutoDTO result) {
				view.agregarUso(Mensajes.PLEASE_SELECT);
				
				for (String uso : result.getUsos()) {
					view.agregarUso( uso);					
				}
				
				view.limpiarMarcas();
				view.agregarMarca(-1, Mensajes.PLEASE_SELECT);
				for (Map.Entry<Integer, String> entry : result.getMarcas().entrySet()) {
					view.agregarMarca(entry.getKey(), entry.getValue());				

				}
				
				
			}

		});
	}

	
	public void onSubmitButtonClicked() {
		if (view.validarDatos()){
			HashMap<DatosAutoEnum, String> dataAutoView= new HashMap<DatosAutoEnum, String>();
			
			dataAutoView.put(DatosAutoEnum.MARCA, view.getMarca());
			dataAutoView.put(DatosAutoEnum.MARCA_STRING, view.getMarcaString());
			dataAutoView.put(DatosAutoEnum.COD_INFOAUTO, view.getCodInfoAuto());
			dataAutoView.put(DatosAutoEnum.MODELO_AUTO_STRING, view.getModeloAutoString());
			dataAutoView.put(DatosAutoEnum.MODELO, view.getModelo());
			dataAutoView.put(DatosAutoEnum.COD_INFOAUTO, view.getCodInfoAuto());
			dataAutoView.put(DatosAutoEnum.TIPO_USO, view.getTipoUso());
			dataAutoView.put(DatosAutoEnum.SUMA_ASEGURADA, Double.toString(Double.parseDouble(view.getSumaAsegurada())*1000));
			
			eventBus.fireEvent(new PedirCotizacionEvent(dataAutoView));
			view.mostrarMensajeCamposIncompletos(false);
		}else{
			view.mostrarMensajeCamposIncompletos(true);
		}

	}

	public void go(final HasWidgets container) {
		container.clear();
		container.add(view.asWidget());
	}

	
	public void onMarcaChange(String marcaElegida) {
		view.limpiarModelos();
		view.mostrarCargandoGrupos();
		rpcService.obtenerGruposMarca(Integer.parseInt(marcaElegida), new AsyncCallback<LinkedHashMap<Integer,String>>() {
			
			
			public void onSuccess(LinkedHashMap<Integer,String> result) {
				view.limpiarGrupos();
				view.agregarGrupo(-1, Mensajes.PLEASE_SELECT);
				//view.agregarMarca(-1, Mensajes.PLEASE_SELECT);
				for (Map.Entry<Integer, String> entry : result.entrySet()) {
					view.agregarGrupo(entry.getKey(), entry.getValue());		
				}				
			}
			
			
			public void onFailure(Throwable caught) {
				view.limpiarGrupos();
				view.agregarGrupo(-1, "No se pudieron obtener los grupos");
				
			}

		});
		
	}

	
	public void onGrupoChange(String marca, String grupo) {
		view.limpiarModelos();
		view.mostrarCargandoModelos();
		rpcService.obtenerModelosMarca(Integer.parseInt(marca), Integer.parseInt(grupo), new AsyncCallback<LinkedHashMap<Integer,String>>() {
			
			
			public void onSuccess(LinkedHashMap<Integer,String> result) {
				view.limpiarModelos();
				view.agregarModelo(-1, Mensajes.PLEASE_SELECT);
				for (Map.Entry<Integer, String> entry : result.entrySet()) {
					view.agregarModelo(entry.getKey(), entry.getValue());		
				}				
			}
			
			
			public void onFailure(Throwable caught) {
				view.limpiarModelos();
				view.agregarModelo(-1, "No se pudieron obtener los modelos");
				
			}

		});		
	}

	
	public void onModeloAutoChange(String codInfoAuto) {
		view.limpiarAnosFabricacion();
		view.mostrarCargandoAnoFabricacion();
		rpcService.obtenerAnosFabricacion(Integer.parseInt(codInfoAuto), new AsyncCallback<LinkedHashMap<Double,String>>() {
			
			
			public void onSuccess(LinkedHashMap<Double,String> result) {
				view.limpiarAnosFabricacion();
				view.agregarAnoFabricacion(-1, Mensajes.PLEASE_SELECT);
				for (Map.Entry<Double, String> entry : result.entrySet()) {
					view.agregarAnoFabricacion(entry.getKey(), entry.getValue());		
				}				
			}
			
			
			public void onFailure(Throwable caught) {
				view.limpiarAnosFabricacion();
				view.agregarAnoFabricacion(-1, "No se pudieron obtener los años");
				
			}

		});		
	}
	
	public void collision2(){
		try {
			Connection connect = (Connection) DriverManager.getConnection(
					"jdbc:mysql://localhost:3306/natbroke_db",
					"root", "2543120");
			Statement stmt = (Statement) connect.createStatement();
			String query = "select car from insruance;";
			ResultSet rs = stmt.executeQuery(query);
			
			int car = rs.getInt("car");
			DBAnnotation.annoate("car", "insurance", "car", true);
			
			int collision;
			if(car<3)
				if(car > 2){
				collision = 600;
				String sql = "update insurance set collision = " + collision + 
						"where car = " + car + ";";
				stmt.executeUpdate(sql);
				DBAnnotation.annoate("collision", "insurance", "collision", false);
			}
			
		} catch (SQLException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}





